@@ -47,11 +47,12 @@ class CropForeignKey(models.ForeignKey):
 
 
 class ImageRatioField(models.CharField):
-    def __init__(self, image_field, size, adapt_rotation=False, verbose_name=None,
+    def __init__(self, image_field, size, adapt_rotation=False, allow_fullsize=False, verbose_name=None,
                  size_warning=getattr(settings, 'IMAGE_CROPPING_SIZE_WARNING', False)):
         self.width, self.height = size.split('x')
         self.image_field = image_field
         self.adapt_rotation = adapt_rotation
+        self.allow_fullsize = allow_fullsize
         self.size_warning = size_warning
         super(ImageRatioField, self).__init__(max_length=255, blank=True, verbose_name=verbose_name)
 
@@ -62,6 +63,7 @@ class ImageRatioField(models.CharField):
             'data-image-field': self.image_field,
             'data-my-name': self.name,
             'data-adapt-rotation': str(self.adapt_rotation).lower(),
+            'data-allow-fullsize': str(self.allow_fullsize).lower(),
             'data-size-warning': str(self.size_warning).lower(),
             'class': 'image-ratio',
         })
