@@ -48,6 +48,13 @@ var image_cropping = {
         onSelect: image_cropping.update_selection($this),
         addClass: ($this.data('size-warning') && ((org_width < min_width) || (org_height < min_height))) ? 'size-warning jcrop-image': 'jcrop-image'
       }
+
+      var cropping_disabled = false;
+      if($this.val()[0] == "-"){
+        cropping_disabled = true;
+        $this.val($this.val().substr(1));
+      }
+
       // is the image bigger than the minimal cropping values?
       // otherwise lock cropping area on full image 
       var initial;
@@ -66,7 +73,36 @@ var image_cropping = {
       // hide the input field, show image to crop instead
       $this.hide().after($image);
 
-      image_cropping.$('#' + image_id).Jcrop(options);
+      image_cropping.$('#' + image_id).Jcrop(options, function(){jcrop=this;});
+
+      if ($this.data('allow-fullsize') == true) {
+        if(cropping_disabled){
+          jcrop.release();
+          $this.val('-'+$this.val());
+        }
+        var label = 'allow-fullsize-'+image_id;
+        var checked = cropping_disabled ? '' : ' checked="checked"';
+        image_cropping.$('<div class="field-box allow-fullsize">' +
+                         '<input type="checkbox" id="'+label+'" name="'+label+'"'+checked+'></div>').appendTo($this.parent());
+        image_cropping.$('<style type="text/css">div.allow-fullsize{padding: 5px 0 0 10px;}</style>').appendTo('head');
+        image_cropping.$('#'+label).click(function(){
+          if (cropping_disabled==true){
+            $this.val($this.val().substr(1));
+            jcrop.setSelect($this.val().split(','));
+            cropping_disabled = false;
+          } else {
+            $this.val('-'+$this.val());
+            jcrop.release();
+            cropping_disabled = true;
+          }
+        });
+        $this.parent().find('.jcrop-tracker').mousedown(function(){
+            if (cropping_disabled){
+              image_cropping.$('#'+label).attr('checked','checked')
+              cropping_disabled = false;
+            }
+        });
+      }
     });
 
     if (image_cropping.$('body').hasClass('change-form')) {
